==> nextcloud-25.0.12p1.tgz: nextcloud/apps/files_external/l10n/is.js <==
OC.L10N.register(
    "files_external",
    {
    "(Group)" : "(Hópur)",
    "Compatibility with Mac NFD encoding (slow)" : "Samhæfni við Mac NFD kóðun (hægvirkt)",
    "Enable encryption" : "Virkja dulritun",
    "Enable previews" : "Virkja forskoðanir",
    "Enable sharing" : "Virkja deilingu",
    "Check for changes" : "Fylgjast með breytingum",
    "Never" : "Aldrei",
    "Once every direct access" : "Einu sinni við hvern beinan aðgang",
    "Read only" : "Skrifvarið",
    "Disconnect" : "Aftengjast",
    "Admin defined" : "Skilgreindur kerfisstjóri",
    "Delete storage?" : "Eyða geymslu?",
    "Saved" : "Vistað",
    "Saving …" : "Vista …",
    "Save" : "Vista",
    "Storage with ID \"%d\" not found" : "Geymsla með auðkennið '%d' fannst ekki",
    "Invalid backend or authentication mechanism class" : "Ógildur flokkur bakenda eða auðkenningartækni",
    "Invalid mount point" : "Ógildur tengipunktur",
    "Objectstore forbidden" : "Hlutageymsla (objectstore) bönnuð",
    "Invalid storage backend \"%s\"" : "Ógildur geymslubakendi \"%s\"",
    "Not permitted to use backend \"%s\"" : "Ekki leyft að nota \"%s\" bakendann",
    "Not permitted to use authentication mechanism \"%s\"" : "Ekki leyft að nota \"%s\" auðkenningartæknina",
    "Unsatisfied backend parameters" : "Óuppfyllt viðföng bakenda",
    "Unsatisfied authentication mechanism parameters" : "Óuppfyllt viðföng auðkenningartækni",
    "Insufficient data: %s" : "Ónóg gögn: %s",
    "%s" : "%s",
    "Storage with ID \"%d\" is not user editable" : "Geymslan með auðkennið '%d' er ekki breytanleg af notanda",
    "Access key" : "Aðgangslykill",
    "Secret key" : "Leynilykill",
    "Builtin" : "Innbyggt",
    "None" : "Ekkert",
    "OAuth1" : "OAuth1",
    "App key" : "Lykill forrits",
    "App secret" : "Leynilykill forrits",
    "OAuth2" : "OAuth2",
    "Client ID" : "Biðlaraauðkenni",
    "Client secret" : "Leynilykill biðlara",
    "OpenStack v2" : "OpenStack v2",
    "Username" : "Notandanafn",
    "Password" : "Lykilorð",
    "Tenant name" : "Nafn handhafa (tenant)",
    "Identity endpoint URL" : "Endapunktur auðkennisslóðar (identity endpoint URL)",
    "OpenStack v3" : "OpenStack v3",
    "Domain" : "Lén",
    "Rackspace" : "Rackspace",
    "API key" : "API-lykill",
    "Global credentials" : "Víðvær innskráningarauðkenni",
    "Log-in credentials, save in database" : "Innskráningarauðkenni, vista í gagnagrunni",
    "Username and password" : "Notandanafn og lykilorð",
    "Log-in credentials, save in session" : "Innskráningarauðkenni, vista í setu",
    "User entered, store in database" : "Innskráður notandi, geyma í gagnagrunni",
    "RSA public key" : "RSA-dreifilykill",
    "Public key" : "Dreifilykill",
    "RSA private key" : "RSA-einkalykill",
    "Private key" : "Einkalykill",
    "Kerberos ticket" : "Kerberos aðgöngumerki",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "Vélarheiti",
    "Port" : "Gátt",
    "Region" : "Svæði",
    "Enable SSL" : "Virkja SSL",
    "Enable Path Style" : "Virkja slóðastíl",
    "Legacy (v2) authentication" : "Eldri (v2) auðkenning",
    "WebDAV" : "WebDAV",
    "URL" : "Slóð (URL)",
    "Remote subfolder" : "Fjartengd undirmappa",
    "Secure https://" : "Öruggt https://",
    "FTP" : "FTP",
    "Host" : "Netþjónn",
    "Secure ftps://" : "Öruggt ftps://",
    "Local" : "Staðvært",
    "Location" : "Staðsetning",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Rót (root)",
    "SFTP with secret key login" : "SFTP innskráning með leynilykli",
    "Share" : "Deila",
    "Show hidden files" : "Sýna faldar skrár",
    "Timeout" : "Tímamörk",
    "Username as share" : "Notandanafn sem sameign",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Heiti á þjónustu",
    "Request timeout (seconds)" : "Tímamörk á beiðni (sekúndur)",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Stuðningur við cURL í PHP er ekki virkjaður eða ekki uppsettur. Tenging %s í skráakerfi er ekki möguleg. Biddu kerfisstjórann þinn um að setja þetta upp.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Stuðningur við FTP í PHP er ekki virkjaður eða ekki uppsettur. Tenging %s í skráakerfi er ekki möguleg. Biddu kerfisstjórann þinn um að setja þetta upp.",
    "\"%1$s\" is not installed. Mounting of %2$s is not possible. Please ask your system administrator to install it." : "\"%1$s\" er ekki uppsett. Tenging %2$s í skráakerfi er ekki möguleg. Biddu kerfisstjórann þinn um að setja þetta upp.",
    "External storage" : "Ytri gagnageymsla",
    "External storage support" : "Stuðningur við utanaðkomandi gagnageymslur",
    "Adds basic external storage support" : "Bætir við grunnstuðningi fyrir utanaðkomandi gagnageymslur",
    "External mount error" : "Villa við tengingu í fjartengdu skráakerfi",
    "Storage type" : "Tegund gagnageymslu",
    "Unknown" : "Óþekkt",
    "Scope" : "Umfang",
    "Personal" : "Einka",
    "System" : "Kerfi",
    "No external storage configured or you don't have the permission to configure them" : "Engin utanaðkomandi gagnageymsla er uppsett eða að þú hefur ekki heimild til að stilla slíkt",
    "Open documentation" : "Opna hjálparskjöl",
    "Folder name" : "Nafn möppu",
    "Authentication" : "Auðkenning",
    "Configuration" : "Uppsetning",
    "Available for" : "Tiltækt fyrir",
    "Click to recheck the configuration" : "Smelltu til að yfirfara aftur uppsetninguna",
    "Add storage" : "Bæta við gagnahirslu",
    "All users" : "Allir notendur",
    "Advanced settings" : "Ítarlegri valkostir",
    "Allow users to mount external storage" : "Leyfa notendum að tengja ytri gagnageymslur í skráakerfi",
    "Grant access" : "Veita aðgengi",
    "Error configuring OAuth1" : "Villa við uppsetningu OAuth1",
    "Please provide a valid app key and secret." : "Settu inn gildan forritslykil og leynilykil (secret).",
    "Error configuring OAuth2" : "Villa við uppsetningu OAuth2",
    "Generate keys" : "Útbúa lykla",
    "Error generating key pair" : "Villa við að útbúa nýtt lyklapar",
    "Empty response from the server" : "Tómt svar frá þjóni móttekið",
    "Couldn't access. Please log out and in again to activate this mount point" : "Náði ekki aðgangi. Skráðu þig út og svo aftur inn til að virkja þennan tengipunkt",
    "Couldn't get the information from the remote server: {code} {type}" : "Gat ekki lesið upplýsingar frá fjartengda þjóninum: {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "Gat ekki fengið lista yfir fjartengda tengipunkta: {type}",
    "There was an error with message: " : "Það kom upp villa með skilaboðunum: ",
    "external-storage" : "ytri-gagnageymsla",
    "Couldn't fetch list of Windows network drive mount points: Empty response from server" : "Gat ekki fengið lista yfir tengipunkta Windows-netdrifa, Svar frá þjóni var tómt",
    "Please enter the credentials for the {mount} mount" : "Settu inn auðkenni fyrir {mount} tengipunktinn",
    "Credentials saved" : "Auðkenni vistuð",
    "Credentials saving failed" : "Vistun auðkenna tókst ekki",
    "Credentials required" : "Auðkenna krafist",
    "Name" : "Nafn"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");

==> nextcloud-26.0.10.tgz: nextcloud/apps/files_external/l10n/is.js <==
OC.L10N.register(
    "files_external",
    {
    "Type to select user or group." : "Skrifaðu til að velja notanda eða hóp.",
    "(Group)" : "(Hópur)",
    "Compatibility with Mac NFD encoding (slow)" : "Samhæfni við Mac NFD kóðun (hægvirkt)",
    "Enable encryption" : "Virkja dulritun",
    "Enable previews" : "Virkja forskoðanir",
    "Enable sharing" : "Virkja deilingu",
    "Check for changes" : "Fylgjast með breytingum",
    "Never" : "Aldrei",
    "Once every direct access" : "Einu sinni við hvern beinan aðgang",
    "Read only" : "Skrifvarið",
    "Disconnect" : "Aftengjast",
    "Admin defined" : "Skilgreindur kerfisstjóri",
    "Delete storage?" : "Eyða geymslu?",
    "Saved" : "Vistað",
    "Saving …" : "Vista …",
    "Save" : "Vista",
    "Forbidden to manage local mounts" : "Bannað að stjórna staðværum tengipunktum",
    "Storage with ID \"%d\" not found" : "Geymsla með auðkennið '%d' fannst ekki",
    "Invalid backend or authentication mechanism class" : "Ógildur flokkur bakenda eða auðkenningartækni",
    "Invalid mount point" : "Ógildur tengipunktur",
    "Objectstore forbidden" : "Hlutageymsla (objectstore) bönnuð",
    "Invalid storage backend \"%s\"" : "Ógildur geymslubakendi \"%s\"",
    "Not permitted to use backend \"%s\"" : "Ekki leyft að nota \"%s\" bakendann",
    "Not permitted to use authentication mechanism \"%s\"" : "Ekki leyft að nota \"%s\" auðkenningartæknina",
    "Unsatisfied backend parameters" : "Óuppfyllt viðföng bakenda",
    "Unsatisfied authentication mechanism parameters" : "Óuppfyllt viðföng auðkenningartækni",
    "Insufficient data: %s" : "Ónóg gögn: %s",
    "%s" : "%s",
    "Storage with ID \"%d\" is not user editable" : "Geymslan með auðkennið '%d' er ekki breytanleg af notanda",
    "Access key" : "Aðgangslykill",
    "Secret key" : "Leynilykill",
    "Builtin" : "Innbyggt",
    "None" : "Ekkert",
    "OAuth1" : "OAuth1",
    "App key" : "Lykill forrits",
    "App secret" : "Leynilykill forrits",
    "OAuth2" : "OAuth2",
    "Client ID" : "Biðlaraauðkenni",
    "Client secret" : "Leynilykill biðlara",
    "OpenStack v2" : "OpenStack v2",
    "Username" : "Notandanafn",
    "Password" : "Lykilorð",
    "Tenant name" : "Nafn handhafa (tenant)",
    "Identity endpoint URL" : "Endapunktur auðkennisslóðar (identity endpoint URL)",
    "OpenStack v3" : "OpenStack v3",
    "Domain" : "Lén",
    "Rackspace" : "Rackspace",
    "API key" : "API-lykill",
    "Global credentials" : "Víðvær innskráningarauðkenni",
    "Log-in credentials, save in database" : "Innskráningarauðkenni, vista í gagnagrunni",
    "Username and password" : "Notandanafn og lykilorð",
    "Log-in credentials, save in session" : "Innskráningarauðkenni, vista í setu",
    "Global credentials, user entered" : "Víðvær innskráningarauðkenni, sett inn af notanda",
    "User entered, store in database" : "Innskráður notandi, geyma í gagnagrunni",
    "RSA public key" : "RSA-dreifilykill",
    "Public key" : "Dreifilykill",
    "RSA private key" : "RSA-einkalykill",
    "Private key" : "Einkalykill",
    "Kerberos default realm, defaults to \"WORKGROUP\"" : "Sjálfgefið Kerberos svæði, er sjálfgefið \"WORKGROUP\"",
    "Kerberos ticket" : "Kerberos aðgöngumerki",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "Vélarheiti",
    "Port" : "Gátt",
    "Region" : "Svæði",
    "Storage Class" : "Flokkur geymslurýmis",
    "Enable SSL" : "Virkja SSL",
    "Enable Path Style" : "Virkja slóðastíl",
    "Legacy (v2) authentication" : "Eldri (v2) auðkenning",
    "WebDAV" : "WebDAV",
    "URL" : "Slóð (URL)",
    "Remote subfolder" : "Fjartengd undirmappa",
    "Secure https://" : "Öruggt https://",
    "FTP" : "FTP",
    "Host" : "Netþjónn",
    "Secure ftps://" : "Öruggt ftps://",
    "Local" : "Staðvært",
    "Location" : "Staðsetning",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Rót (root)",
    "SFTP with secret key login" : "SFTP innskráning með leynilykli",
    "SMB/CIFS" : "SMB/CIFS",
    "Share" : "Deila",
    "Show hidden files" : "Sýna faldar skrár",
    "Case sensitive file system" : "Skráakerfi háð há/lágstöfum",
    "Verify ACL access when listing files" : "Athuga ACL-aðgang þegar gerðir eru listar yfir skrár",
    "Timeout" : "Tímamörk",
    "SMB/CIFS using OC login" : "SMB / CIFS með OC-innskráningu",
    "Username as share" : "Notandanafn sem sameign",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Heiti á þjónustu",
    "Request timeout (seconds)" : "Tímamörk á beiðni (sekúndur)",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Stuðningur við cURL í PHP er ekki virkjaður eða ekki uppsettur. Tenging %s í skráakerfi er ekki möguleg. Biddu kerfisstjórann þinn um að setja þetta upp.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Stuðningur við FTP í PHP er ekki virkjaður eða ekki uppsettur. Tenging %s í skráakerfi er ekki möguleg. Biddu kerfisstjórann þinn um að setja þetta upp.",
    "\"%1$s\" is not installed. Mounting of %2$s is not possible. Please ask your system administrator to install it." : "\"%1$s\" er ekki uppsett. Tenging %2$s í skráakerfi er ekki möguleg. Biddu kerfisstjórann þinn um að setja þetta upp.",
    "External storage" : "Ytri gagnageymsla",
    "External storage support" : "Stuðningur við utanaðkomandi gagnageymslur",
    "Adds basic external storage support" : "Bætir við grunnstuðningi fyrir utanaðkomandi gagnageymslur",
    "Enter missing credentials" : "Settu inn auðkenni sem vantar",
    "Unable to update this external storage config. {statusMessage}" : "Tókst ekki að uppfæra uppsetningu þessarar ytri-gagnageymslu. {statusMessage}",
    "New configuration successfully saved" : "Það tókst að vista nýju uppsetninguna",
    "There was an error with this external storage." : "Það kom upp villa með þessa ytri-gagnageymslu.",
    "We were unable to check the external storage {basename}" : "Okkur tókst ekki að athuga ytri-gagnageymsluna {basename}",
    "Examine this faulty external storage configuration" : "Skoða þessa ófullgerðu uppsetningu ytri-gagnageymslu",
    "Open in Files" : "Opna í skráaforritinu",
    "There was an error with this external storage. Do you want to review this mount point config in the settings page?" : "Það kom upp villa með þessa ytri-gagnageymslu. Viltu yfirfara uppsetningu þessa tengipunkts á stillingasíðunni?",
    "External mount error" : "Villa við tengingu í fjartengdu skráakerfi",
    "List of external storage." : "Listi yfir ytri-gagnageymslur.",
    "There is no external storage configured. You can configure them in your Personal settings." : "Engin utanaðkomandi gagnageymsla er uppsett. Þú getur stillt slíkt í einkastillingunum þínum.",
    "There is no external storage configured and you don't have the permission to configure them." : "Engin utanaðkomandi gagnageymsla er uppsett og þú hefur ekki heimild til að stilla slíkt.",
    "No external storage" : "Engin ytri-gagnageymsla",
    "Storage type" : "Tegund gagnageymslu",
    "Unknown" : "Óþekkt",
    "Scope" : "Umfang",
    "Personal" : "Einka",
    "System" : "Kerfi",
    "No external storage configured or you don't have the permission to configure them" : "Engin utanaðkomandi gagnageymsla er uppsett eða að þú hefur ekki heimild til að stilla slíkt",
    "Open documentation" : "Opna hjálparskjöl",
    "Folder name" : "Nafn möppu",
    "Authentication" : "Auðkenning",
    "Configuration" : "Uppsetning",
    "Available for" : "Tiltækt fyrir",
    "Click to recheck the configuration" : "Smelltu til að yfirfara aftur uppsetninguna",
    "Add storage" : "Bæta við gagnahirslu",
    "All users" : "Allir notendur",
    "Advanced settings" : "Ítarlegri valkostir",
    "Allow users to mount external storage" : "Leyfa notendum að tengja ytri gagnageymslur í skráakerfi",
    "Grant access" : "Veita aðgengi",
    "Error configuring OAuth1" : "Villa við uppsetningu OAuth1",
    "Please provide a valid app key and secret." : "Settu inn gildan forritslykil og leynilykil (secret).",
    "Error configuring OAuth2" : "Villa við uppsetningu OAuth2",
    "Generate keys" : "Útbúa lykla",
    "Error generating key pair" : "Villa við að útbúa nýtt lyklapar",
    "Empty response from the server" : "Tómt svar frá þjóni móttekið",
    "Couldn't access. Please log out and in again to activate this mount point" : "Náði ekki aðgangi. Skráðu þig út og svo aftur inn til að virkja þennan tengipunkt",
    "Couldn't get the information from the remote server: {code} {type}" : "Gat ekki lesið upplýsingar frá fjartengda þjóninum: {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "Gat ekki fengið lista yfir fjartengda tengipunkta: {type}",
    "There was an error with message: " : "Það kom upp villa með skilaboðunum: ",
    "external-storage" : "ytri-gagnageymsla",
    "Couldn't fetch list of Windows network drive mount points: Empty response from server" : "Gat ekki fengið lista yfir tengipunkta Windows-netdrifa, Svar frá þjóni var tómt",
    "Please enter the credentials for the {mount} mount" : "Settu inn auðkenni fyrir {mount} tengipunktinn",
    "Credentials saved" : "Auðkenni vistuð",
    "Credentials saving failed" : "Vistun auðkenna tókst ekki",
    "Credentials required" : "Auðkenna krafist",
    "Name" : "Nafn"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
